@@ -19,6 +19,7 @@ extern int nstvars,real_nstvars;
 
 #ifdef REORDER
 extern int reorder, reorder_bits, reorder_size, reorder_maxsize;
+extern float reorder_factor;
 #endif
 #ifdef OTHER_SIMP
 extern int option_gc_factor;
@@ -1521,7 +1522,7 @@ static force_garbage()
   if(reduce_table.elements_in_table/BDDS_IN_MB > option_gc_limit) {
     option_gc_limit = reduce_table.elements_in_table/BDDS_IN_MB + 1;
     if(verbose)
-      fprintf(stderr,"increase the memory limit to %dMB (%d bdd nodes)\n",
+      fprintf(stderr,"increase memory limit to %dMB (%d bdd nodes)\n",
 	      option_gc_limit,option_gc_limit*BDDS_IN_MB);
   }
   maxnodes=next_gc_size(reduce_table.elements_in_table);
@@ -1570,8 +1571,10 @@ mygarbage()
 {
 #ifdef REORDER
   if(((reduce_table.elements_in_table) >= maxnodes)
-     || (reorder && reduce_table.elements_in_table > max(5*last_reorder_size/4,
-							 reorder_size)
+/*       || (reorder && reduce_table.elements_in_table > max(5*last_reorder_size/4, */
+/*  							 reorder_size) */
+     || (reorder && reduce_table.elements_in_table
+            > max((int)(reorder_factor*last_reorder_size), reorder_size)
 #ifdef OTHER_SIMP
 	 && reduce_table.elements_in_table <= reorder_maxsize
 	 && !disable_reorder
