@@ -9,6 +9,7 @@ extern int heuristics,verbose,option_print_reachable,
   option_incremental,option_restrict_trans, option_interactive,
   option_AG_only, option_conj_part, option_changes_only;
 extern int option_print_node_length;
+extern int option_print_width;
 extern int interactive_mode;
 extern int conj_part_limit;
 extern double fudge_factor;
@@ -25,6 +26,7 @@ extern int reorder;
 extern int reorder_bits;
 extern int reorder_size;
 extern int reorder_maxsize;
+extern float reorder_factor;
 #endif
 #ifdef OTHER_SIMP
 extern int option_othersimp;
@@ -40,6 +42,8 @@ extern int option_output_often;
 /* Quit after outputting the order file with -quit option (default),
    but don't quit with -noquit. */
 extern int option_quit;
+/* Whether to write a pid file */
+extern int option_pid;
 #endif
 
 extern node_ptr atom_stack;
@@ -66,12 +70,6 @@ char **argv;
 
   for(i = 0 ; i < 32 ; i++)
     signal(i, signal_handler);
-
-  { 
-    FILE *ff = fopen(".smv-pid","w");
-    fprintf(ff,"%d",getpid());
-    fclose(ff);
-  }
 #endif
   init_storage();
   addrstart = (char *) sbrk(0);
@@ -89,6 +87,12 @@ char **argv;
       option_round_robin = 1;
       continue;
     }
+    if(strcmp(*argv,"-nopid")==0){
+      argv++;
+      argc--;
+      option_pid = 0;
+      continue;
+    }
     if(strcmp(*argv,"-r")==0){
       argv++;
       argc--;
@@ -246,6 +250,10 @@ char **argv;
       argv++;
       sscanf(*(argv++),"%d",&option_print_node_length);
     }
+    else if(strcmp(*argv,"-width")==0){
+      argv++;
+      sscanf(*(argv++),"%d",&option_print_width);
+    }
     else if(strcmp(*argv,"-k")==0){
       argv++;
       sscanf(*(argv++),"%d",&KEYTABLESIZE);
@@ -277,6 +285,10 @@ char **argv;
       argv++;
       sscanf(*(argv++),"%d",&reorder_maxsize);
     }
+    else if(strcmp(*argv, "-reorderfactor") == 0) {
+      argv++;
+      sscanf(*(argv++),"%f",&reorder_factor);
+    }
 #endif
     else rpterr("undefined: %s",*argv);
     argc -= 2;
@@ -286,6 +298,15 @@ char **argv;
   option_gc_limit -= (KEYTABLESIZE*sizeof(bdd_ptr)
 		      + APPLY_CACHE_SIZE*sizeof(apply_rec))/(1024*1024);
 #endif
+#ifdef SMV_SIGNALS
+  if(option_pid){ 
+    FILE *ff = fopen(".smv-pid","w");
+    if(ff != NULL) {
+      fprintf(ff,"%d",getpid());
+      fclose(ff);
+    }
+#endif
+  }
   if(verbose){
     fprintf(stderr,"Key table size: %d\n",KEYTABLESIZE);
     fprintf(stderr,"Apply cache size: %d\n",APPLY_CACHE_SIZE);
@@ -295,6 +316,9 @@ char **argv;
 #ifdef OTHER_SIMP
     fprintf(stderr,"GC factor: %d, memory limit (adjusted): %dMB (%d BDD nodes)\n",
 	    option_gc_factor,option_gc_limit,option_gc_limit*BDDS_IN_MB);
+    fprintf(stderr,"Reordering: ");
+    if(reorder) fprintf(stderr,"ON, "); else fprintf(stderr,"OFF, "); 
+    fprintf(stderr,"Factor: %f\n",reorder_factor);
     if(option_early && option_AG_only && option_forward_search)
       fprintf(stderr,"Using early evaluation of AG specs\n");
     fprintf(stderr,"Simplification algorithm: ");
